function [sufficientOverlap, error] = computeOverlap(sourceTransform, referenceTransform, overlapThreshold)

    % Input: 
    % - sourceTransform: source frame projected onto reference frame plane
    % - referenceTransform: reference frame projected onto same space
    % - overlapThreshold: sufficient number of pixels overlapping between 
    % projected source and reference frames to ensure good homography
    
    % Output: 
    % - sufficientOverlap: boolean indicating whether sufficient overlap is
    % found between projected source and reference frame
    % - error: raw pixel intensity error between projected source
    % and reference frames in the overlapping region
    
    nnzReference = find(referenceTransform);
    nnzSource = find(sourceTransform);
    nnzCommon = intersect(nnzReference, nnzSource);
    
    error = sqrt(sum(sum(sum((sourceTransform(nnzCommon) - referenceTransform(nnzCommon)).^2)))) / numel(nnzCommon);
    
    disp({'Overlap:', numel(nnzCommon)});
    disp({'Error:', error});
    
    sufficientOverlap = numel(nnzCommon) > overlapThreshold;
end