function [homography, projectedImage] = transformImage(frames, ...
    sourceFrameIndex, referenceFrameIndex, pastHomographies, xrange, yrange)

    % Input: 
    % - frames: 4D array of frames
    % - sourceFrameIndex: index of the frame to be projected
    % - referenceFrameIndex: index of the frame to be projected to
    % - pastHomographies: 2D cell array caching previously computed
    % homographies from every frame to every other frame
    % - xrange, yrange: dimensions of the output image
    
    % Output: 
    % - homography: homography from source frame to reference frame
    % - imageTransform: projected source frame with dimensions (xrange, yrange)
       

    if numel(pastHomographies{sourceFrameIndex, referenceFrameIndex}) ~= 1
        homography = pastHomographies(sourceFrameIndex, referenceFrameIndex);
    else
        homography = compute_homography(frames(:,:,:,sourceFrameIndex), frames(:,:,:,referenceFrameIndex));
        pastHomographies{sourceFrameIndex, referenceFrameIndex} = homography;
    end
    sourceFrame = frames(:,:,:,sourceFrameIndex);
    T = maketform('projective', homography');
    projectedImage = imtransform(sourceFrame, T, 'XData', xrange, 'YData', yrange);
end